Specifies the droplets that are in the test set and debris set. The test set consists of droplets that will be classified by DIEM, the labels of which are allowed to change during the EM. The debris set consists of droplets with labels fixed to the debris group during the EM.
set_debris_test_set(x, top_n = 10000, min_counts = 100,
min_genes = 100, fix_debris = NULL, verbose = FALSE)An SCE object.
A numeric value giving the total number of test droplets
and take the counts of the top_n ranked droplet. Set to NULL
to disable and set all droplets above min_counts and
min_genes to the test set.
A numeric value that specifies the minimum total read/UMI counts a test droplet can have.
A numeric value that specifies the minimum total genes detected a test droplet can have.
A character vector of droplet IDs that will be assigned to the debris set, regardless of its total counts or genes detected.
verbosity
An SCE object.
min_counts and min_genes specify the lower limit
that droplets in the test set must have. In addition,
the parameter top_n specifies that at most the top top_n
should be included in the test set. The default is 10,000
in accordance with the typical maximum number of droplets
generated during a single-cell experiment, but should be changed
accordingly.
If the read/UMI count of the top_n count-ranked droplet is greater
than min_counts, then the min_counts is
increased to this limit. The fix_debris parameter allows
additional flexibility in specifying those droplets that are
included in the debris set. For example, it may be useful to
set droplets above a pre-determined MT
regardless of the total number of read/UMI counts present.